@@ -12,7 +12,8 @@ from . import config
 class LivemarkRendererMixin(HTMLRenderer):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.__counter = 0
+        self.__tables = 0
+        self.__charts = 0
 
     # Render
 
@@ -31,7 +32,7 @@ class LivemarkRendererMixin(HTMLRenderer):
         return str(html)
 
     def render_fenced_code(self, element):
-        if "table" in element.lang or "table" in element.extra:
+        if element.lang == "table":
             spec_yaml = str(element.children[0].children).strip()
             spec_python = yaml.safe_load(spec_yaml)
             spec_python["licenseKey"] = "non-commercial-and-evaluation"
@@ -43,17 +44,17 @@ class LivemarkRendererMixin(HTMLRenderer):
             spec = json.dumps(spec_python, ensure_ascii=False)
             spec = spec.replace("'", "\\'")
             template = Template(config.TABLE)
-            self.__counter += 1
-            text = template.render(spec=spec, elem=f"livemark-{self.__counter}")
+            self.__tables += 1
+            text = template.render(spec=spec, elem=f"livemark-table-{self.__tables}")
             return text
-        if "chart" in element.lang or "chart" in element.extra:
+        if element.lang == "chart":
             spec_yaml = str(element.children[0].children).strip()
             spec_python = yaml.safe_load(spec_yaml)
             spec = json.dumps(spec_python, ensure_ascii=False)
             spec = spec.replace("'", "\\'")
             template = Template(config.CHART)
-            self.__counter += 1
-            text = template.render(spec=spec, elem=f"livemark-{self.__counter}")
+            self.__charts += 1
+            text = template.render(spec=spec, elem=f"livemark-chart-{self.__charts}")
             return text
         return super().render_fenced_code(element)
 
